@@ -17,7 +17,7 @@ class Actor:
     def __init__(self, connector: Connector, queue:asyncio.Queue = None, loop=None) -> None:
         self.queue = queue or asyncio.Queue()
         self.connector = connector
-        self.loop = loop
+        self.loop = loop or asyncio.get_event_loop()
         self._provided = False
 
         self.assignments = {}
@@ -75,6 +75,7 @@ class Actor:
             await reserve_handler.pass_done()
 
         except Exception as e:
+            console.print_exception()
             await reserve_handler.pass_exception(e)
 
     async def _on_unreserve_message(self, message: BouncedUnreserveMessage):
@@ -87,6 +88,7 @@ class Actor:
             del self.reserve_handler_map[message.data.reservation]
             await unreserve_handler.pass_done()
         except Exception as e:
+            console.print_exception()
             await unreserve_handler.pass_exception(e)
 
             
@@ -176,12 +178,14 @@ class Actor:
 
         await assign_handler.log(f"Assignment received", level=DebugLevel.INFO)
         try:
-            args, kwargs = await expandInputs(node=self.template.node, args=assign.data.args, kwargs=assign.data.kwargs) if self.expandInputs else assign.data.args, assign.data.kwargs
             try:
+                args, kwargs = await expandInputs(node=self.template.node, args=assign.data.args, kwargs=assign.data.kwargs) if self.expandInputs else (assign.data.args, assign.data.kwargs)
+           
                 await self._assign(assign_handler, reserve_handler, args, kwargs) # We dont do all of the handling here, as we really want to have a generic class for Generators and Normal Functions
             
             except Exception as e:
                 # As broad as possible to send further
+                console.print_exception()
                 await assign_handler.pass_exception(e)
                 # Pass this further up
                 raise
