@@ -1,5 +1,4 @@
-from enum import Enum
-from pydantic.main import BaseModel
+from ..progress import ProgressDataModel
 from ....messages.types import  PROVIDE, PROVIDE_DONE, PROVIDE_PROGRESS, UNPROVIDE_PROGRESS
 from ....messages.base import MessageDataModel, MessageMetaExtensionsModel, MessageMetaModel, MessageModel
 from typing import List, Optional
@@ -15,15 +14,6 @@ class MetaModel(MessageMetaModel):
     extensions: Optional[MetaExtensionsModel]
 
 
-class ProgressLevel(str, Enum):
-    INFO = "INFO"
-    DEBUG = "DEBUG"
-
-
-class DataModel(MessageDataModel):
-    level: ProgressLevel
-    message: str
-
 class UnprovideProgressMessage(MessageModel):
-    data: DataModel
+    data: ProgressDataModel
     meta: MetaModel
\ No newline at end of file
