@@ -1,4 +1,4 @@
-from bergen.enums import HostProtocol, PostmanProtocol, ProviderProtocol
+from bergen.enums import DataPointType, HostProtocol, PostmanProtocol, ProviderProtocol
 from bergen.queries.delayed.pod import POD_QUERY
 from bergen.queries.delayed.template import TEMPLATE_GET_QUERY
 from bergen.extenders.port import ArgPortExtender, KwargPortExtender, ReturnPortExtender
@@ -59,8 +59,10 @@ class DataPoint(ArnheimModel):
     secure: Optional[bool]
     inward: Optional[str]
     outward: Optional[str]
+    distinct: Optional[str]
     port: Optional[int]
     url: Optional[str]
+    distinct: Optional[str]
     models: Optional[List[DataModel]]
 
     class Meta:
@@ -89,11 +91,20 @@ class EntertainerSettings(ArnheimObject):
     type: Optional[HostProtocol]
     kwargs: Optional[dict]
 
+class WardSettings(ArnheimObject):
+    distinct: Optional[str]
+    needsNegotiation: Optional[str]
+    type: Optional[DataPointType]
+    host: Optional[str]
+    port: Optional[int]
+    secure: Optional[bool]
+
 class Transcript(ArnheimObject):
     postman: Optional[PostmanSettings]
     host: Optional[EntertainerSettings]
     provider: Optional[ProviderSettings]
     models: Optional[List[DataModel]]
+    wards: Optional[List[WardSettings]]
 
 
 class Provider(ArnheimModel):
