@@ -24,17 +24,17 @@ NEGOTIATION_GQL = TypedGQL("""
       needsNegotiation: $needsNegotiation
   ) {
     timestamp
+    wards {
+        distinct
+        type
+        needsNegotiation
+        host
+        port
+    }
     models {
         identifier
         point {
-            app {
-                name
-            }
-            id
-            outward
-            port
-            type
-            needsNegotiation
+            distinct
         }
     }
     postman {
