@@ -22,7 +22,7 @@ class IntWidget(BaseWidgetMixin, QWidget):
     def __init__(self, *args, **kwargs) -> None:
         super().__init__(*args, **kwargs)
 
-        self.numberInput = QLineEdit(self.port.default)
+        self.numberInput = QLineEdit(str(self.port.default))
         self.validator  = QIntValidator()
         self.numberInput.setValidator(self.validator)
         self.numberInput.textChanged.connect(self.valueChanged)
