@@ -18,39 +18,37 @@ import requests
 class AIOHttpGraphQLWard(BaseGraphQLWard):
     can_subscribe = False
 
-    def __init__(self, port, host, protocol, token, loop=None, needs_negotiation=False) -> None:
-        super().__init__(port=port, host=host, protocol=protocol, token=token, loop=loop)
-        self.needs_negotiation = needs_negotiation
-
-    async def configure(self):
-        self.transport = AIOHTTPTransport(url=self._graphql_endpoint, headers=self._headers)
-        await self.transport.connect()
+    async def connect(self):
+        self.async_transport = AIOHTTPTransport(url=self._graphql_endpoint, headers=self._headers)
+        await self.async_transport.connect()
 
     async def negotiate(self):
         if self.needs_negotiation:
-            print("Negotiation")
             query_node = gql("""
                 mutation Negotiate {
                     negotiate
                 }
             """)
-            response = await self.transport.execute(query_node, variable_values={})
+            response = await self.async_transport.execute(query_node, variable_values={})
             return response.data["negotiate"]
         else:
             return None
-
-
+    
 
     async def run_async(self, the_query: TypedGQL, variables: dict = {}, **kwargs):
         query_node = gql(the_query.query)
         try:
-            response = await self.transport.execute(query_node, variable_values=variables)
+            response = await self.async_transport.execute(query_node, variable_values=variables)
+
+            if response.errors:
+                raise GraphQLException(f"Ward {self._graphql_endpoint}:" + str(response.errors))
+            
+            return the_query.extract(response.data)
+
         except:
             console.print_exception(show_locals=True)
+            raise 
             
-        if response.errors:
-            raise GraphQLException(f"Ward {self._graphql_endpoint}:" + str(response.errors))
-        return the_query.extract(response.data)
-
+        
     async def disconnect(self):
-        await self.transport.close()
\ No newline at end of file
+        await self.async_transport.close()
\ No newline at end of file
